# MONKE - is a event-based socket wrapper

> how to install

```sh
pip install monke
```

navigate to examples folder of this repo to know how u can make your own server-client event based communication thing.